package main

import (
	"flag"
	"log"
	"os"
	"os/signal"
	"syscall"

	"git.loafle.net/commons_go/logging"
	"git.loafle.net/overflow/overflow_probe_container_network/server"
)

var (
	pidPath *string
)

func init() {
	pidPath = flag.String("pid-path", "/tmp/network-container.pid", "The path of pid file")
	flag.Parse()
}

func main() {
	defer logging.Logger().Sync()

	s := server.New(*pidPath)

	go func() {
		if err := s.Start(); nil != err {
			log.Printf("Server: Start error %v", err)
			return
		}
	}()

	// // Set up channel on which to send signal notifications.
	// // We must use a buffered channel or risk missing the signal
	// // if we're not ready to receive when the signal is sent.
	interrupt := make(chan os.Signal, 1)
	signal.Notify(interrupt,
		syscall.SIGKILL,
		syscall.SIGSTOP,
		syscall.SIGHUP,
		syscall.SIGINT,
		syscall.SIGTERM,
		syscall.SIGQUIT)

	<-interrupt

	s.Stop()

}
